import { expect } from 'chai'
import DocsSitemap from './index'
import propsSpec from './props'

testComponent(
  () => DocsSitemap,
  { props: propsSpec },
  ({ render, testTagAndClass, propValue }) => {
    testTagAndClass('div', 'g-docs-sitemap')

    it('should render a <div/> tag for each category', () => {
      const wrapper = render()

      expect(wrapper.find('.g-docs-sitemap').find('.category').length).to.equal(
        propValue('order').length
      )
    })

    it('should render category title', () => {
      const wrapper = render()

      expect(
        wrapper
          .find('.g-docs-sitemap')
          .find('.category')
          .first()
          .find('.category-title')
          .text()
      ).to.equal(propValue('order')[0].title)
      expect(
        wrapper
          .find('.g-docs-sitemap')
          .find('.category')
          .at(1)
          .find('.category-title')
          .text()
      ).to.equal(propValue('order')[1].title)
    })

    it('should render all category items', () => {
      const wrapper = render()

      const order = propValue('order')
      const data = propValue('data')

      order.forEach((item, firstIndex) => {
        item.docs.forEach((doc, secondIndex) => {
          expect(
            wrapper
              .find('.g-docs-sitemap')
              .find('.category')
              .at(firstIndex)
              .find('.item')
              .at(secondIndex)
              .find('a')
              .attr('href')
          ).to.equal(`/${doc}`)

          const match = data.find(datum => {
            return datum.path === doc
          })

          expect(
            wrapper
              .find('.g-docs-sitemap')
              .find('.category')
              .at(firstIndex)
              .find('.item')
              .at(secondIndex)
              .find('a')
              .attr('dangerouslySetInnerHTML').__html
          ).to.contain(match.data.sidebar_title)
        })
      })
    })
  }
)
